@@ -4,7 +4,7 @@ from PIL import Image
 from django.contrib.auth.decorators import login_required
 from django.shortcuts import get_object_or_404, redirect
 from django.template import RequestContext
-from django.http import HttpResponseRedirect, Http404, HttpResponse
+from django.http import HttpResponseRedirect
 from django.core.urlresolvers import reverse
 from django.contrib import messages
 from django.template.defaultfilters import slugify
@@ -13,6 +13,7 @@ from django.conf import settings
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.base.http import Http403
 from tendenci.core.base.views import file_display
+from tendenci.core.perms.decorators import is_enabled
 from tendenci.core.perms.utils import (get_notice_recipients,
     has_perm, has_view_perm, get_query_filters, update_perms_and_save)
 from tendenci.core.event_logs.models import EventLog
@@ -29,6 +30,7 @@ from tendenci.core.base.utils import send_email_notification
 from tendenci.addons.directories.utils import resize_s3_image
 
 
+@is_enabled('directories')
 def details(request, slug=None, template_name="directories/view.html"):
     if not slug: return HttpResponseRedirect(reverse('directories'))
     directory = get_object_or_404(Directory, slug=slug)
@@ -41,6 +43,8 @@ def details(request, slug=None, template_name="directories/view.html"):
     else:
         raise Http403
 
+
+@is_enabled('directories')
 def search(request, template_name="directories/search.html"):
     get = dict(request.GET)
     query = get.pop('q', [])
@@ -81,6 +85,7 @@ def search_redirect(request):
     return HttpResponseRedirect(reverse('directories'))
 
 
+@is_enabled('directories')
 def print_view(request, slug, template_name="directories/print-view.html"):
     directory = get_object_or_404(Directory, slug=slug)    
     if has_view_perm(request.user,'directories.view_directory',directory):
@@ -90,8 +95,9 @@ def print_view(request, slug, template_name="directories/print-view.html"):
             context_instance=RequestContext(request))
     else:
         raise Http403
-    
 
+
+@is_enabled('directories')
 @login_required
 def add(request, form_class=DirectoryForm, template_name="directories/add.html"):
     can_add_active = has_perm(request.user,'directories.add_directory')
@@ -182,7 +188,9 @@ def add(request, form_class=DirectoryForm, template_name="directories/add.html")
 
     return render_to_response(template_name, {'form':form}, 
         context_instance=RequestContext(request))
-    
+
+
+@is_enabled('directories')
 @login_required
 def edit(request, id, form_class=DirectoryForm, template_name="directories/edit.html"):
     directory = get_object_or_404(Directory, pk=id)
@@ -234,14 +242,9 @@ def edit(request, id, form_class=DirectoryForm, template_name="directories/edit.
         context_instance=RequestContext(request))
 
 
+@is_enabled('directories')
 @login_required
 def edit_meta(request, id, form_class=MetaForm, template_name="directories/edit-meta.html"):
-
-    # check permission
-    directory = get_object_or_404(Directory, pk=id)
-    if not has_perm(request.user,'directories.change_directory',directory):
-        raise Http403
-
     defaults = {
         'title': directory.get_title(),
         'description': directory.get_description(),
@@ -266,6 +269,7 @@ def edit_meta(request, id, form_class=MetaForm, template_name="directories/edit-
         context_instance=RequestContext(request))
 
 
+@is_enabled('directories')
 def logo_display(request, id):
     directory = get_object_or_404(Directory, pk=id)
 
@@ -277,6 +281,7 @@ def logo_display(request, id):
     return file_display(request, directory.logo.name)
 
 
+@is_enabled('directories')
 @login_required
 def delete(request, id, template_name="directories/delete.html"):
     directory = get_object_or_404(Directory, pk=id)
@@ -306,6 +311,7 @@ def delete(request, id, template_name="directories/delete.html"):
         raise Http403
 
 
+@is_enabled('directories')
 @login_required
 def pricing_add(request, form_class=DirectoryPricingForm, template_name="directories/pricing-add.html"):
     if has_perm(request.user,'directories.add_directorypricing'):
@@ -324,7 +330,9 @@ def pricing_add(request, form_class=DirectoryPricingForm, template_name="directo
             context_instance=RequestContext(request))
     else:
         raise Http403
-    
+
+
+@is_enabled('directories')
 @login_required
 def pricing_edit(request, id, form_class=DirectoryPricingForm, template_name="directories/pricing-edit.html"):
     directory_pricing = get_object_or_404(DirectoryPricing, pk=id)
@@ -344,6 +352,7 @@ def pricing_edit(request, id, form_class=DirectoryPricingForm, template_name="di
         context_instance=RequestContext(request))
 
 
+@is_enabled('directories')
 @login_required
 def pricing_view(request, id, template_name="directories/pricing-view.html"):
     directory_pricing = get_object_or_404(DirectoryPricing, id=id)
@@ -355,7 +364,9 @@ def pricing_view(request, id, template_name="directories/pricing-view.html"):
             context_instance=RequestContext(request))
     else:
         raise Http403
-    
+
+
+@is_enabled('directories')
 @login_required
 def pricing_delete(request, id, template_name="directories/pricing-delete.html"):
     directory_pricing = get_object_or_404(DirectoryPricing, pk=id)
@@ -375,6 +386,8 @@ def pricing_delete(request, id, template_name="directories/pricing-delete.html")
     return render_to_response(template_name, {'directory_pricing': directory_pricing}, 
         context_instance=RequestContext(request))
 
+
+@is_enabled('directories')
 def pricing_search(request, template_name="directories/pricing-search.html"):
     directory_pricing = DirectoryPricing.objects.filter(status=True).order_by('duration')
     EventLog.objects.log()
@@ -382,6 +395,8 @@ def pricing_search(request, template_name="directories/pricing-search.html"):
     return render_to_response(template_name, {'directory_pricings':directory_pricing}, 
         context_instance=RequestContext(request))
 
+
+@is_enabled('directories')
 @login_required
 def pending(request, template_name="directories/pending.html"):
     can_view_directories = has_perm(request.user, 'directories.view_directory')
@@ -395,7 +410,9 @@ def pending(request, template_name="directories/pending.html"):
 
     return render_to_response(template_name, {'directories': directories},
             context_instance=RequestContext(request))
-    
+
+
+@is_enabled('directories')
 @login_required
 def approve(request, id, template_name="directories/approve.html"):
     can_view_directories = has_perm(request.user, 'directories.view_directory')
@@ -445,7 +462,9 @@ def approve(request, id, template_name="directories/approve.html"):
 
 def thank_you(request, template_name="directories/thank-you.html"):
     return render_to_response(template_name, {}, context_instance=RequestContext(request))
-    
+
+
+@is_enabled('directories')
 @login_required
 def export(request, template_name="directories/export.html"):
     """Export Directories"""
@@ -502,6 +521,8 @@ def export(request, template_name="directories/export.html"):
     return render_to_response(template_name, {
     }, context_instance=RequestContext(request))
 
+
+@is_enabled('directories')
 def renew(request, id, form_class=DirectoryRenewForm, template_name="directories/renew.html"):
     can_add_active = has_perm(request.user,'directories.add_directory')
     require_approval = get_setting('module', 'directories', 'renewalrequiresapproval')
