@@ -20,7 +20,8 @@ from tendenci.addons.events.models import (
     Event, Place, RegistrationConfiguration, Payment,
     Sponsor, Organizer, Speaker, Type, TypeColorSet,
     RegConfPricing, Addon, AddonOption, CustomRegForm,
-    CustomRegField, CustomRegFormEntry, CustomRegFieldEntry
+    CustomRegField, CustomRegFormEntry, CustomRegFieldEntry,
+    Registrant
 )
 
 from form_utils.forms import BetterModelForm
@@ -1469,6 +1470,7 @@ class RegConfPricingBaseModelFormSet(BaseModelFormSet):
 
 class MessageAddForm(forms.ModelForm):
     #events = forms.CharField()
+    subject = forms.CharField(widget=forms.TextInput(attrs={'style':'width:100%;padding:5px 0;'}))
     body = forms.CharField(widget=TinyMCE(attrs={'style':'width:100%'},
         mce_attrs={'storme_app_label':Email._meta.app_label,
         'storme_model':Email._meta.module_name.lower()}),
@@ -1485,7 +1487,7 @@ class MessageAddForm(forms.ModelForm):
 
     class Meta:
         model = Email
-        fields = ('body',)
+        fields = ('subject', 'body',)
 
     def __init__(self, event_id=None, *args, **kwargs):
         super(MessageAddForm, self).__init__(*args, **kwargs)
@@ -1590,3 +1592,30 @@ class AddonOptionForm(forms.ModelForm):
 
 class EventICSForm(forms.Form):
     user = forms.ModelChoiceField(queryset=User.objects.all())
+
+
+class RegistrantSearchForm(forms.Form):
+    event = forms.ModelChoiceField(queryset=Event.objects.filter(registration__isnull=False).distinct('pk'),
+                                   label=_("Event"),
+                                   required=False,
+                                   empty_label='All Events')
+    start_dt = forms.DateField(label=_('Start Date'), required=False)
+    end_dt = forms.DateField(label=_('End Date'), required=False)
+
+    user_id = forms.CharField(label=_('User ID'), required=False)
+    first_name = forms.CharField(label=('First Name'), required=False)
+    last_name = forms.CharField(label=('Last Name'), required=False)
+    email = forms.CharField(label=('Email'), required=False)
+
+    def __init__(self, *args, **kwargs):
+        super(RegistrantSearchForm, self).__init__(*args, **kwargs)
+
+        # Set start date and end date
+        if self.fields.get('start_dt'):
+            self.fields.get('start_dt').widget.attrs = {
+                'class': 'datepicker',
+            }
+        if self.fields.get('end_dt'):
+            self.fields.get('end_dt').widget.attrs = {
+                'class': 'datepicker',
+            }
