@@ -54,19 +54,29 @@ class PhotoAdminForm(TendenciBaseForm):
                 'classes': ['admin-only'],
                 })]
 
+
 class PhotoUploadForm(TendenciBaseForm):
-    
+
     class Meta:
         model = Image
-        exclude = ('member', 'photoset', 'title_slug', 'effect', 'crop_from', 'group', 'photoset_position')
+        exclude = (
+          'member',
+          'photoset',
+          'title_slug',
+          'effect',
+          'crop_from',
+          'group',
+          'photoset_position'
+        )
 
     def __init__(self, *args, **kwargs):
         super(PhotoUploadForm, self).__init__(*args, **kwargs)
 
+
 class PhotoBatchEditForm(TendenciBaseForm):
     class Meta:
         model = Image
-        exclude=(
+        exclude = (
             'title_slug',
             'creator_username',
             'owner_username',
@@ -79,6 +89,7 @@ class PhotoBatchEditForm(TendenciBaseForm):
             'status_detail',
         )
 
+
 class PhotoEditForm(TendenciBaseForm):
 
     status_detail = forms.ChoiceField(
