@@ -1,5 +1,8 @@
 # django
+import math
+import time
 from datetime import datetime, timedelta
+from django.db import models
 from django.contrib.auth.decorators import login_required
 from django.shortcuts import render_to_response, get_object_or_404, redirect, Http404
 from django.template import RequestContext
@@ -12,16 +15,21 @@ from django.utils.translation import ugettext as _
 from django.core.exceptions import ImproperlyConfigured
 from django.contrib import messages
 from django.conf import settings
+from django.db import connection
 # for password change
 from django.views.decorators.csrf import csrf_protect
 
 from djcelery.models import TaskMeta
 from johnny.cache import invalidate
 
-from tendenci.core.base.decorators import ssl_required
+from tendenci.core.base.decorators import ssl_required, password_required
+from tendenci.core.base.utils import get_pagination_page_range
 
 from tendenci.core.perms.object_perms import ObjectPermission
-from tendenci.core.perms.utils import (has_perm, update_perms_and_save, get_notice_recipients, get_query_filters)
+from tendenci.core.perms.utils import (has_perm, update_perms_and_save,
+                                       get_notice_recipients,
+                                       get_query_filters
+                                       )
 from tendenci.core.base.http import Http403
 from tendenci.core.event_logs.models import EventLog
 from tendenci.core.site_settings.utils import get_setting
@@ -36,7 +44,7 @@ from tendenci.apps.user_groups.forms import GroupMembershipEditForm
 
 from tendenci.apps.profiles.models import Profile
 from tendenci.apps.profiles.forms import (ProfileForm, ExportForm, UserPermissionForm, 
-UserGroupsForm, ValidatingPasswordChangeForm, UserMembershipForm)
+UserGroupsForm, ValidatingPasswordChangeForm, UserMembershipForm, ProfileMergeForm)
 from tendenci.apps.profiles.tasks import ExportProfilesTask
 from tendenci.addons.events.models import Registrant
 
@@ -105,7 +113,7 @@ def index(request, username='', template_name="profiles/index.html"):
         memberships = user_this.membershipdefault_set.filter(
             status=True) & user_this.membershipdefault_set.filter(
                 active_qs | expired_qs)
-    
+
     registrations = Registrant.objects.filter(user=user_this)
 
     EventLog.objects.log(instance=profile)
@@ -138,52 +146,84 @@ def search(request, template_name="profiles/search.html"):
     allow_anonymous_search = get_setting('module', 'users', 'allowanonymoususersearchuser')
     allow_user_search = get_setting('module', 'users', 'allowusersearch')
     membership_view_perms = get_setting('module', 'memberships', 'memberprotection')
+    only_members = request.GET.get('members', None)
 
-    if request.user.is_anonymous():
-        if not allow_anonymous_search:
-            raise Http403
+    # hide "only members" checkbox
+    # special occasion when box does nothing
+    show_checkbox = not all((
+        not allow_user_search,
+        membership_view_perms in ['all-members', 'member-type'],
+        not request.user.profile.is_superuser,
+    ))
 
-    if request.user.is_authenticated():
-        if not allow_user_search and not request.user.profile.is_superuser:
-            raise Http403
 
-    members = request.GET.get('members', None)
+    if not request.user.profile.is_superuser:
+        # block anon
+        if request.user.is_anonymous():
+            if not allow_anonymous_search:
+                raise Http403
+            if not allow_user_search:
+                raise Http403
+
+        # block member or user
+        if request.user.is_authenticated():
+            if request.user.profile.is_member:  # if member
+                if membership_view_perms == 'private':
+                    if not allow_user_search:
+                        raise Http403
+            else:  # if just user
+                if not allow_user_search:
+                    raise Http403
+
     query = request.GET.get('q', None)
     filters = get_query_filters(request.user, 'profiles.view_profile')
+
     profiles = Profile.objects.filter(Q(status=True), Q(status_detail="active"), Q(filters)).distinct()
 
     if query:
-        profiles = profiles.filter(Q(status=True), Q(status_detail="active"), Q(user__first_name__icontains=query) | Q(user__last_name__icontains=query) | Q(user__email__icontains=query) | Q(user__username__icontains=query) | Q(display_name__icontains=query) | Q(company__icontains=query))
+        profiles = profiles.filter(
+            Q(user__first_name__icontains=query) | \
+            Q(user__last_name__icontains=query) | \
+            Q(user__email__icontains=query) | \
+            Q(user__username__icontains=query) | \
+            Q(display_name__icontains=query) | \
+            Q(company__icontains=query)
+        )
 
-    is_not_member_filter = (Q(member_number="") | Q(user__is_active=False))
-    if members:
-        if not request.user.profile.is_superuser:
-            if membership_view_perms == "private":
-                profiles = profiles.filter(is_not_member_filter)
-            elif membership_view_perms == "all-members" or membership_view_perms == "member-type":
-                if request.user.profile and request.user.profile.is_member:
-                    profiles = profiles.exclude(is_not_member_filter)
-                else:
-                    profiles = profiles.filter(is_not_member_filter)
-            else:
-                profiles = profiles.exclude(is_not_member_filter)
-        else:
-            profiles = profiles.exclude(is_not_member_filter)
-    else:
-        if not request.user.profile.is_superuser:
-            if membership_view_perms == "private":
-                    profiles = profiles.filter(is_not_member_filter)
-            elif membership_view_perms == "all-members" or membership_view_perms == "member-type":
-                if not request.user.profile or not request.user.profile.is_member:
-                    profiles = profiles.filter(is_not_member_filter)
+    # if non-superuser
+        # if is member
+        # if is user
+        # if only_members
+            # exclude non-members
 
     if not request.user.profile.is_superuser:
+        if request.user.profile.is_member:
+
+            if membership_view_perms == 'private':
+                profiles = profiles.exclude(~Q(member_number=''))  # exclude all members
+            elif membership_view_perms == 'member-type':
+                profiles = profiles.exclude(  # exclude specific members
+                    ~Q(user__membershipdefault__membership_type__in=request.user.membershipdefault_set.values_list('membership_type', flat=True))
+                )
+            elif membership_view_perms == 'all-members':
+                pass  # exclude nothing
+
+            if not allow_user_search:
+                profiles = profiles.exclude(member_number='')  # exclude non-members
+
+        else:
+            if membership_view_perms != 'public':
+                profiles = profiles.exclude(~Q(member_number=''))  # exclude all members
+
         profiles = profiles.exclude(hide_in_search=True)
 
+    if only_members:
+        profiles = profiles.exclude(member_number='')  # exclude non-members
+
     profiles = profiles.order_by('user__last_name', 'user__first_name')
 
     EventLog.objects.log()
-    return render_to_response(template_name, {'profiles': profiles, "user_this": None},
+    return render_to_response(template_name, {'profiles': profiles, 'show_checkbox': show_checkbox, 'user_this': None},
         context_instance=RequestContext(request))
 
 
@@ -849,6 +889,254 @@ def user_membership_add(request, username, form_class=UserMembershipForm, templa
                             'user_this': user,
                             }, context_instance=RequestContext(request))
 
+
+@login_required
+def similar_profiles(request, template_name="profiles/similar_profiles.html"):
+    if not request.user.profile.is_superuser:
+        raise Http403
+
+    if request.method == 'POST':
+        # generate a unique id for this import
+        sid = str(int(time.time()))
+
+        # store the info in the session to pass to the next page
+        request.session[sid] = {'users': request.POST.getlist('id_users')}
+        return HttpResponseRedirect(reverse(
+                                    'profile.merge_view',
+                                    args=[sid]))
+
+    users_with_duplicate_name = []
+    users_with_duplicate_email = []
+
+#    duplicate_names = User.objects.values_list('first_name', 'last_name'
+#                                          ).annotate(
+#                                        num_last=Count('last_name')
+#                                        ).annotate(
+#                                        num_first=Count('first_name')
+#                                        ).filter(num_last__gt=1,
+#                                                num_first__gt=1
+#                                        ).exclude(
+#                                        first_name='',
+#                                        last_name=''
+#                                        ).order_by('last_name', 'first_name')
+    # use raw sql to get the accurate number of duplicate names
+    sql = """
+            SELECT first_name , last_name
+            FROM auth_user
+            WHERE first_name <> '' and last_name <> ''
+            GROUP BY first_name , last_name
+            HAVING count(*) > 1
+            ORDER BY last_name, first_name
+        """
+    cursor = connection.cursor()
+    cursor.execute(sql)
+    duplicate_names = cursor.fetchall()
+
+    duplicate_emails = User.objects.values_list('email', flat=True
+                                    ).annotate(
+                                    num_emails=Count('email')
+                                    ).filter(num_emails__gt=1
+                                             ).exclude(email=''
+                                            ).order_by('email')
+    len_duplicate_names = len(duplicate_names)
+    len_duplicate_emails = len(duplicate_emails)
+    # total groups of duplicates
+    total_groups = len_duplicate_names + len_duplicate_emails
+
+    num_groups_per_page = 20
+    num_pages = int(math.ceil(total_groups * 1.0 / num_groups_per_page))
+    try:
+        curr_page = int(request.GET.get('page', 1))
+    except:
+        curr_page = 1
+    if curr_page <= 0 or curr_page > num_pages:
+        curr_page = 1
+    page_range = get_pagination_page_range(num_pages,
+                                           curr_page=curr_page)
+    # slice the duplicate_names and duplicate_emails
+    start_index = (curr_page - 1) * num_groups_per_page
+    end_index = curr_page * num_groups_per_page
+    if len_duplicate_names > 1:
+        if start_index <= len_duplicate_names - 1:
+            if end_index < len_duplicate_names:
+                duplicate_names = duplicate_names[start_index:end_index]
+            else:
+                duplicate_names = duplicate_names[start_index:]
+        else:
+            duplicate_names = []
+    if len_duplicate_emails > 1:
+        if end_index < len_duplicate_names:
+            duplicate_emails = []
+        else:
+            start_index = start_index - len_duplicate_names
+            end_index = end_index - len_duplicate_names
+            if start_index < 0:
+                start_index = 0
+
+            if end_index > len_duplicate_emails:
+                end_index = len_duplicate_emails
+
+            if start_index < end_index:
+                duplicate_emails = duplicate_emails[start_index:end_index]
+            else:
+                duplicate_emails = []
+
+    for dup_name in duplicate_names:
+        if dup_name[0] and dup_name[1]:
+            users = User.objects.filter(
+                        first_name=dup_name[0],
+                        last_name=dup_name[1])
+            users_with_duplicate_name.append(users)
+    for email in duplicate_emails:
+        if email:
+            users = User.objects.filter(
+                        email=email)
+            users_with_duplicate_email.append(users)
+
+    return render_to_response(template_name, {
+        'users_with_duplicate_name': users_with_duplicate_name,
+        'users_with_duplicate_email': users_with_duplicate_email,
+        'curr_page': curr_page,
+        'prev': curr_page - 1,
+        'next': curr_page + 1,
+        'num_pages': num_pages,
+        'page_range': page_range,
+        'user_this': None,
+    }, context_instance=RequestContext(request))
+
+
+@login_required
+def merge_profiles(request, sid, template_name="profiles/merge_profiles.html"):
+
+    if not request.user.profile.is_superuser:
+        raise Http403
+
+    sid = str(sid)
+    users_ids = (request.session[sid]).get('users', [])
+    profiles = []
+    for user_id in users_ids:
+        profile = Profile.objects.get_or_create(user_id=user_id,
+                                    defaults={
+                                    'creator_id': request.user.id,
+                                    'creator_username': request.user.username,
+                                    'owner_id': request.user.id,
+                                    'owner_username': request.user.username
+                                    })[0]
+        profiles.append(profile)
+    form = ProfileMergeForm(request.POST or None,
+                            list=(request.session[sid]).get('users', []))
+    if request.method == 'POST':
+        if form.is_valid():
+            sid = str(int(time.time()))
+            request.session[sid] = {'master': form.cleaned_data["master_record"],
+                                    'users': form.cleaned_data['user_list']}
+            # let them re-enter password on the real merge
+            request.session['password_promt'] = False
+            return HttpResponseRedirect(reverse(
+                                    'profile.merge_process',
+                                    args=[sid]))
+
+    return render_to_response(template_name, {
+        'form': form,
+        'profiles': profiles,
+    }, context_instance=RequestContext(request))
+
+
+@login_required
+@password_required
+def merge_process(request, sid):
+
+    if not request.user.profile.is_superuser:
+        raise Http403
+
+    sid = str(sid)
+    master = (request.session[sid]).get('master', '')
+    users = (request.session[sid]).get('users', '')
+
+    if master and users:
+        # get description for event log before users get deleted
+        description = 'Master user: %s, merged user(s): %s.' % (
+                        '%s %s (%s)(id=%d)' % (master.user.first_name,
+                                       master.user.last_name,
+                                       master.user.username,
+                                       master.user.id),
+                        ', '.join(['%s %s (%s)(id=%d)' % (
+                        profile.user.first_name,
+                        profile.user.last_name,
+                        profile.user.username,
+                        profile.user.id
+                        ) for profile in users if profile != master]))
+
+        related = master.user._meta.get_all_related_objects()
+        field_names = master._meta.get_all_field_names()
+
+        valnames = dict()
+        for r in related:
+            if not r.model is Profile:
+                valnames.setdefault(r.model, []).append(r.field)
+
+        for profile in users:
+            if profile != master:
+                for field in field_names:
+                    if getattr(master, field) == '':
+                        setattr(master, field, getattr(profile, field))
+
+                for model, fields in valnames.iteritems():
+                    for field in fields:
+                        if not isinstance(field, models.OneToOneField):
+                            objs = model.objects.filter(**{field.name: profile.user})
+                            # handle unique_together fields. for example, GroupMembership
+                            # unique_together = ('group', 'member',)
+                            [unique_together] = model._meta.unique_together[:1] or [None]
+                            if unique_together and field.name in unique_together:
+                                for obj in objs:
+                                    field_values = [getattr(obj, field_name) for field_name in unique_together]
+                                    field_dict = dict(zip(unique_together, field_values))
+                                    # switch to master user
+                                    field_dict[field.name] = master.user
+                                    # check if the master record exists
+                                    if model.objects.filter(**field_dict).exists():
+                                        obj.delete()
+                                    else:
+                                        obj.update(**{field.name: master.user}) 
+                            else:
+                                if objs.exists():
+                                    objs.update(**{field.name: master.user})
+                        else: # OneToOne
+                            [obj] = model.objects.filter(**{field.name: profile.user})[:1] or [None]
+                            if obj:
+                                [master_obj] = model.objects.filter(**{field.name: master.user})[:1] or [None]
+                                if not master_obj:
+                                    setattr(obj, field.name, master.user)
+                                    obj.save()
+                                else:
+                                    obj_fields = master_obj._meta.get_all_field_names()
+                                    updated = False
+                                    for fld in obj_fields:
+                                        master_val = getattr(master_obj, fld)
+                                        if master_val == '' or master_val is None:
+                                            val = getattr(obj, fld)
+                                            if val != '' and not val is None:
+                                                setattr(master_obj, fld, val)
+                                                updated = True
+                                    if updated:
+                                        master_obj.save()
+                                    # delete obj
+                                    obj.delete()
+
+                master.save()
+                profile.user.delete()
+                profile.delete()
+
+        # log an event
+        EventLog.objects.log(description=description[:120])
+        invalidate('profiles_profile')
+        messages.add_message(request, messages.SUCCESS, 'Successfully merged users. %s' % description)
+
+    request.session['password_promt'] = False
+    return redirect("profile.search")
+
+
 @login_required
 def export(request, template_name="profiles/export.html"):
     """Create a csv file for all the users
