@@ -14,4 +14,4 @@ class Command(BaseCommand):
         call_command('expire_stories')
         call_command('send_event_reminders')
         call_command('send_membership_notices')
-        call_command('remove_expired_memberships')
+        call_command('clean_memberships')
